@@ -1,17 +1,17 @@
 
 /*
-    Copyright 2000  Li-Cheng (Andy) Tai
-
+    Copyright 2000, 2002  Li-Cheng (Andy) Tai
+ 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation; either version 2 of the License, or
     (at your option) any later version.
-
+ 
     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
-
+ 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
@@ -41,48 +41,49 @@ DRAWING_TOOL ;
        image_buf_set_modified(ibuf, 1);\
        /*image_buf_pixmap_to_rgbbuf(ibuf, 0);*/\
     }
-      
+
 
 
 
 typedef struct image_buf
 {
-   GdkPixbuf *rgbbuf, *regionbuf; 
-   GdkPixmap *pixmap; 
-   GdkGC *gc;
-   GtkWidget *window;
-   GtkWidget *drawing_area;
-   char *name;
-   GtkWidget *current_button;
-   DRAWING_TOOL current_tool, saved_tool;
-   GdkCursor *cursor;
-   GdkFont *font;
-   int filled;
-   int timer;
-   int flash_state;
-   
-   GdkPoint pts[MAX_NUM_POINTS]; /* a temporary array for storing points */
-   int num_pts;
-   int ptdiffx;
-   int ptdiffy;
-   
-   int modified;
-   int has_focus;
-   int lx;
-   int ly;
-   int mx;
-   int my;
-   int llx;
-   int lly;
-   
-   int lpx;
-   int lpy;
-   
-   char textbuf[MAX_TEXT_LENGTH];
-   
-   int current_palette;
-   GdkColor palettes[NUM_PALETTE_ENTRIES];
-} image_buf;
+    GdkPixbuf *rgbbuf, *regionbuf;
+    GdkPixmap *pixmap;
+    GdkGC *gc;
+    GtkWidget *window;
+    GtkWidget *drawing_area;
+    char *name;
+    GtkWidget *current_button;
+    DRAWING_TOOL current_tool, saved_tool;
+    GdkCursor *cursor;
+    GdkFont *font;
+    int filled;
+    int timer;
+    int flash_state;
+
+    GdkPoint pts[MAX_NUM_POINTS]; /* a temporary array for storing points */
+    int num_pts;
+    int ptdiffx;
+    int ptdiffy;
+
+    int modified;
+    int has_focus;
+    int lx;
+    int ly;
+    int mx;
+    int my;
+    int llx;
+    int lly;
+
+    int lpx;
+    int lpy;
+
+    char textbuf[MAX_TEXT_LENGTH];
+
+    int current_palette;
+    GdkColor palettes[NUM_PALETTE_ENTRIES];
+}
+image_buf;
 
 
 int image_buf_width(image_buf*);
@@ -92,7 +93,7 @@ int image_buf_rowstride(image_buf*);
 int image_buf_pixelsize(image_buf*);
 
 void image_buf_set_cursor(image_buf *, GdkCursor*);
-void image_buf_set_font(image_buf *, GdkFont*, const char *);
+void image_buf_set_font(image_buf *, const char *);
 
 void image_buf_process_in_place(image_buf *, void (*f)(image_buf *, image_buf *));
 void image_buf_set_name(image_buf* ibuf, const char *n);
